@@ -4,11 +4,11 @@ from os import environ, path
 from subprocess import call
 
 if not environ.get('DESTDIR', ''):
-    PREFIX = environ.get('MESON_INSTALL_PREFIX', '/usr/local')
+    PREFIX = environ.get('MESON_INSTALL_PREFIX', '/usr')
     DATA_DIR = path.join(PREFIX, 'share')
     print('Updating icon cache...')
     call(['gtk-update-icon-cache', '-qtf', path.join(DATA_DIR, 'icons/hicolor')])
     print("Compiling new schemas")
     call(["glib-compile-schemas", path.join(DATA_DIR, 'glib-2.0/schemas')])
     print("Updating desktop database")
-    call(["update-desktop-database", path.join(DATA_DIR, 'applications')])
\ No newline at end of file
+    call(["update-desktop-database", path.join(DATA_DIR, 'applications')])
